package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`/@`!`````"9``#0```!(LP```````#0`(``+
M`"@`&P`:``8````T````-`!``#0`0`!@`0``8`$```0````$`````P```)0!
M``"4`4``E`%``!H````:````!`````$````!````````````0````$``-!(`
M`#02```$`````!````$`````(````"!````@0`#M,0``[3$```4`````$```
M`0````!@````8$```&!``#A&```X1@``!``````0```!````@*X``("^0`"`
MOD``@`,``+03```&`````!````(```"(K@``B+Y``(B^0``8`0``&`$```8`
M```$````!````+`!``"P`4``L`%``$0```!$````!`````0```!0Y71D0)\`
M`$"?0`!`GT``[````.P````$````!````%'E=&0`````````````````````
M``````8````0````4N5T9("N``"`OD``@+Y``(`!``"``0``!`````$````O
M;&EB>#,R+VQD+6QI;G5X+7@S,BYS;RXR````!````!0````#````1TY5`"\3
M^J,609K4EC'<3Z-5(VO_:WU/!````!`````!````1TY5```````#````!```
M```````1````2@````@````(`````!`0!"5`!(`H````H(8`@(`!```+*`0(
M.*`218H```@`````2@```$T```!0````40```%<```!8````60```%L```!<
M`````````%X```!?````8````&$``````````````&[%WQ_.WD<M:W^:?"[%
MF[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3#13BGC)BV^W;S>.>#3J7"W^IG)OAIP(*H^#[20``````````
M```````````[`@`````````````2````U0(`````````````$@````X!````
M`````````!(````2`P`````````````2````F@(`````````````$@```)4`
M`````````````!(````#`0`````````````1````E0$`````````````$@``
M`$`"`````````````!(````3`0`````````````2````2`(`````````````
M$@```"0!`````````````!(````R`P`````````````2````$P``````````
M````(````!P"`````````````!(````J`P`````````````2````[@(`````
M````````$@```"H"`````````````!(```!3`P`````````````A````50$`
M````````````$@```+8``````````````!(```!%`0`````````````2````
M"P(`````````````$@```&\"`````````````!(````W`0`````````````2
M````40(`````````````$@```"(``````````````"````"S`0``````````
M```2````W0(`````````````$@```#X``````````````"````",`@``````
M```````2````6```````````````$@```(4!`````````````!(```!4`P``
M```````````1````=0``````````````$@````($`````````````!(```#R
M```````````````2````A@``````````````$@```+4"`````````````!(`
M``!^`@`````````````2````.0,`````````````$@```+P"````````````
M`!(```#^`@`````````````2````U@``````````````$@````L#````````
M`````!(```!I`@`````````````2````=P$`````````````$@```(4"````
M`````````!(```!W`@`````````````2````YP(`````````````$0```&D!
M`````````````!(```#R`0`````````````2````DP(`````````````$@``
M`%(#`````````````!$````8`0`````````````2````H0(`````````````
M$@```!P#`````````````!(````&`@`````````````2````7`,`````````
M````$@```,H"`````````````!(```"G`@`````````````2````H0``````
M````````$@```$`#`````````````!(```!B`@`````````````2````H`$`
M````````````$@```.4``````````````!$```"^`0`````````````1````
MK`$`````````````$@```"("`````````````!(```!>`0`````````````2
M````9@``````````````$@```/4"`````````````!(```#$````````````
M```2````"P0``/!00`!=````$@`-`%P$``!`0D``Z@H``!(`#0!-`P``X"-`
M`!H"```2``T`?`,````\0``%````$@`-`*H#```P34``L0,``!(`#0""!```
M$#Q``.L!```2``T`2P0```#"0```````$``8`(T#````/D``)````!(`#0#`
M`P``T$!``&H````2``T`%P0```!@0``$````$0`/`#,$``#@.D``+@```!(`
M#0!7!```--)````````0`!@`<`0``&!!0`#4````$@`-`"8$``#PP4``````
M`!``%P#D`P``,#Y``-L````2``T`:00```#"0```````$``7`(\$``#\P4``
M!````!$`%P":`P``P%%```4````2``T`+`0````F0``P````$@`-`#L$``!0
M44``90```!(`#0`H!```\,%````````@`!<`\`,``$!!0``>````$@`-`,X#
M``!0.T``J@```!(`#0"9!```$#]``+T!```2``T``&QI8G!E<FPN<V\N-2XS
M,"XP`%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M
M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?
M;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?
M9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D
M;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S
M<&5C:69I8P!R96%D`%]?97)R;F]?;&]C871I;VX`8VQO<V4`;'-E96LV-`!O
M<&5N-C0`;&EB8RYS;RXV`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K
M7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`
M<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C
M:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?
M>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S
M=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`
M<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R
M7V%T9F]R:P!L:6)C<GEP="YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`
M<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA
M;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/
M7W-T9&EN7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I
M;FET`%]?8G-S7W-T87)T`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C$V`"]U<W(O;&EB>#,R+W!E<FPU+S4N,S`N,"]X.#9?
M-C0M<&QD+6QI;G5X+6=N=7@S,BUT:')E860M;75L=&DO0T]210````(``@``
M``(``@`````````"``(``@````(````#``(``@`#``(``````````P`"````
M`@```````@````(```````(````"```````"``(``@`"``(````"``(````"
M``(``@````,``@`"`````@`"``,``@`"``(````"``(``````````@`#````
M```"`````0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!`.(!```0````(````):1E@8```,`I@0````````!``$`
M,0(``!``````````EI&6!@```@"F!````````*"_0``&!P```````*B_0``&
M#````````+"_0``&#@```````+B_0``&&P```````,"_0``&'@```````,B_
M0``&(0```````-"_0``&(@```````-B_0``&(P```````."_0``&,@``````
M`.B_0``&/P```````/"_0``&0@```````/B_0``&0P```````!C`0``'`0``
M`````"#`0``'`@```````"C`0``'`P```````##`0``'!````````#C`0``'
M!0```````$#`0``'!@```````$C`0``'"````````%#`0``'"0```````%C`
M0``'"@```````&#`0``'"P```````&C`0``'#0```````'#`0``'#P``````
M`'C`0``'$````````(#`0``'$0```````(C`0``'$@```````)#`0``'%```
M`````)C`0``'%0```````*#`0``'%@```````*C`0``'%P```````+#`0``'
M&````````+C`0``'&0```````,#`0``'&@```````,C`0``''````````-#`
M0``''0```````-C`0``''P```````.#`0``'(````````.C`0``')```````
M`/#`0``')0```````/C`0``')@````````#!0``')P````````C!0``'*```
M`````!#!0``'*0```````!C!0``'*@```````"#!0``'*P```````"C!0``'
M+````````##!0``'+0```````#C!0``'+@```````$#!0``'+P```````$C!
M0``',````````%#!0``',0```````%C!0``',P```````&#!0``'-```````
M`&C!0``'-0```````'#!0``'-P```````'C!0``'.````````(#!0``'.0``
M`````(C!0``'.@```````)#!0``'.P```````)C!0``'/````````*#!0``'
M/0```````*C!0``'/@```````+#!0``'0````````+C!0``'00```````,#!
M0``'1````````,C!0``'10```````-#!0``'1@```````-C!0``'1P``````
M`.#!0``'2````````.C!0``'20``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S__T%458/L*(E\)`R-?"0,B70D"(UT)`B)5"0$C50D!&2+!"48````B40D
M'#'`Z)____^+-9&;``"+/;N;``!(B?+HJRT``(L%Q9L``&>`.``/A"D!``"+
M+66;``!GBWT`Z'S^__]GBWT`9X"(!@,```+H:_[__V>`B`8#```!BT0D#(UX
M!8'_____/P^':`$``,'G`NCX_O__1(M,)`B+5"0,QP6=K0``!````$B)P8D%
MD*T``$&)P+X!````9T&+`6>)`8T%(#T``&>)003'P/S!0`!GBP!GB4$(C04,
M/0``9XE!#(/Z`7X9#Q^``````&=!BSRQ9T&)?+`,@\8!.?)U[F=!QT20#```
M``"+/3ZM``"#P@-%,<"--1(6``#HC?O__T&)Q(7`#X2#````BST<K0``C6PD
M&.B3_?__,<!(B>Z-/7P[``#H4P\``$B%P'1RBSWXK```Z!/[___H?OS__XM$
M)!QD,P0E&`````^%H0```(/$*$2)X%U!7,/H+?S__XD%QZP``$B)QX7`='OH
M>_S__XLM)9H``&>+?0#H//W__V?&@*D&````Z:K^__^+/9FL``#HA/O__T&)
MQ.EJ____BSV"K```A?]T"N@]*P``Z7K___^-/9LZ``!(B>[HN@X``(D%8*P`
M`(G'A<`/A%S____KUHLU&IH``(T]<CH``#'`Z&7]__^_`0```.@[^O__Z(;[
M__]F#Q]$``#S#Q[Z,>U!B=&+-"2#Q`2)XH/D\%!40<?`P%%``,?!4%%``,?'
MX"-``/\5N9D``/3S#Q[ZPV8N#Q^$``````"0C3VZFP``C06TFP``.?AT$(L%
M8ID``(7`=`:)P/_@9I##9F8N#Q^$```````/'T``C3V*FP``C36$FP``*?Z)
M\,'N'\'X`@'&T?YT%(L%+ID``(7`=`J)P/_@9@\?1```PV9F+@\?A```````
M#Q]``(`]29L```!U%U6)Y>A_____Q@4XFP```5W#9@\?1```PV9F+@\?A```
M````#Q]``.N.9BX/'X0```````\?0`!!54%455.![%@!``!DBP0E&````(F$
M)$P!```QP(GBD&>+3(<<#\EGB0R"@\`!@_@0=>V-C"0``0``9@\?1```9XM"
M-&<S0B"#P@1G,T($9S-"_-'`9XE"/#G*=>-GBR]GBU\0BP0D9T2+5PB)ZF=$
MBT\,9T2+7P1!B>S!P@5%B="+3"0$0<',`HV$`YEY@EI$BVPD#`'"1(G008V,
M"9EY@EI$,<A$(=A$,<@!T$2)VL'*`D$QT(G602'H1#'F13'0(<9!`<B)P3'6
MP<@"P<$%0HV4*IEY@EI$BVPD$$$!R(M,)`A!C8P*F7F"6@'.1(G!P<$%`<Y$
MB>$QP40AP4'!R`)$,>%'C:0LF7F"6D2+;"04`=&)\L'"!0'1B<)$,<(A\C'"
M0HV$*)EY@EI$BVPD&$0!XD&)S$'!Q`7!S@)$`>)%B<1!,?1!(<S!R0)%,<1'
MC80HF7F"6D2+;"0<1`'@08G40<'$!40!X$&)]$$QS$$AU,'*`D$Q]$*-M"Z9
M>8):1(ML)"!%`>!!B<1!P<0%10'@08G,03'402'$P<@"03',0HV,*9EY@EI$
MBVPD)$0!YD6)Q$'!Q`5$`>9!B=1!,<1%(<1!P<@"03'40HV4*IEY@EI$BVPD
M*$0!X4&)]$'!Q`5$`>%!B<1%,<1!(?3!S@)!,<1"C80HF7F"6D2+;"0L1`'B
M08G,0<'$!40!XD6)Q$$Q]$$AS,')`D4QQ$>-A"B9>8):1(ML)#!$`>!!B=1!
MP<0%1`'@08GT03',02'4P<H"03'T0HVT+IEY@EI$BVPD-$4!X$&)Q$'!Q`5%
M`>!!B<Q!,=1!(<3!R`)!,<Q"C8PIF7F"6D2+;"0X1`'F18G$0<'$!40!YD&)
MU$$QQ$4AQ$$QU$*-E"J9>8):1(ML)#Q$`>%!B?1!P<0%1`'A0<'(`D&)Q$4Q
MQ$$A],'.`D$QQ$*-A"B9>8):1(ML)$!$`>)!B<Q!P<0%1`'B18G$03'T02',
MP<D"13'$1XV$*)EY@EI$BVPD1$0!X$&)U$'!Q`5$`>!!B?1!,<Q!(=3!R@)!
M,?1"C;0NF7F"6D2+;"1(10'$08G`0<'`!44!Q$&)R$$QT$$AP,'(`D$QR$*-
MC"F9>8):1(ML)$Q!`?!$B>;!Q@5!`?")UC'&1"'F,=9!P<P"0HV4*IEY@EH!
MSD2)P<'!!0'.B<%$,>%$(<$QP0'*B?'!P04!RD2)P42+1"10P<D"0HV$`*'K
MV6Y%B>!!,<A!,?#!S@)!`<")T$&)]8G.P<`%1#'N00'`BT0D5#'608V$!*'K
MV6X!QD2)P,'`!0'&B="+5"18P<@"C901H>O9;D2)Z3'!1#'!0<'(`@'1B?+!
MP@4!T8M4)%Q%C:05H>O9;HG"1#'",?)$`>)!B<S!S@)!P<0%1`'B1(MD)&!&
MC:0@H>O9;D2)P#'P,<C!R0)$`>!!B=1!P<0%1`'@1(MD)&1'C:0@H>O9;D&)
M\$$QR$$QT,'*`D4!X$&)Q$'!Q`5%`>!$BV0D:$:-I":AZ]ENB<XQUC'&P<@"
M1`'F18G$0<'$!40!YD2+9"1L1HVD(:'KV6Z)T3'!1#'!0<'(`D0!X4&)]$'!
MQ`5$`>%$BV0D<$:-I"*AZ]ENB<)$,<(Q\D0!XD&)S$'!Q`5$`>)$BV0D=,'.
M`D:-I""AZ]EN1(G`,?`QR,')`D0!X$&)U$'!Q`5$`>!$BV0D>$>-I""AZ]EN
M08GP03'(03'0P<H"10'@08G$0<'$!44!X$2+9"1\1HVD)J'KV6Z)SC'6,<;!
MR`)$`>9%B<1!P<0%1`'F1(ND)(````!&C:0AH>O9;HG1,<%$,<%!P<@"1`'A
M08GT0<'$!40!X42+I"2$````1HVD(J'KV6Z)PD0QPC'RP<X"1`'B08G,0<'$
M!40!XD2+I"2(````1HVD(*'KV6Y$B<`Q\#'(P<D"1`'@08G40<'$!40!X$2+
MI"2,````1XV$(*'KV6Y!B?1!,<Q!,=3!R@)%`<1!B<!!P<`%10'$1(N$))``
M``!"C;0&H>O9;D&)R$$QT$$QP,'(`D$!\$2)YL'&!4$!\(NT))0```"-C#&A
MZ]ENB=8QQD0QYD'!S`(!SD2)P<'!!0'.BXPDF````(V4"J'KV6Z)P40QX40Q
MP4'!R`(!T8GR18G%P<(%`=&+E"2<````C800H>O9;D2)XD0QPC'R`<*)R,'.
M`L'`!4$A]0'"1(G`"?`AR,')`D0)Z$2+K"2@````1XVD+-R\&X]!B?5$`>!!
MB=1!(<U!P<0%1`'@08GT00G,02'4P<H"10GL1(NL)*0```!'C80HW+P;CT&)
MS44!X$&)Q$$AU4'!Q`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDJ````$*-M"[<
MO!N/08G51`'F18G$02'%0<'$!40!YD&)U$$)Q$4AQ$4)[$2+K"2L````0HV,
M*=R\&X]!B<5$`>%!B?1!P<@"0<'$!44AQ40!X4&)Q$4)Q$$A],'.`D4)[$2+
MK"2P````0HV4*MR\&X]%B<5$`>)!B<Q!(?5!P<0%1`'B18G$00GT02',P<D"
M10GL1(NL)+0```!"C80HW+P;CT&)]40!X$&)U$$AS4'!Q`5$`>!!B?1!"<Q!
M(=3!R@)%">Q$BZPDN````$>-A"C<O!N/08G-10'@08G$02'50<'$!44!X$&)
MS$$)U$$AQ$4)[$2+K"2\````0HVT+MR\&X]!B=5$`>9%B<3!R`)!P<0%02'%
M1`'F08G400G$12'$0<'(`D4)[$2+K"3`````0HV,*=R\&X]!B<5$`>%!B?1%
M(<5!P<0%1`'A08G$10G$02'TP<X"10GL1(NL),0```!"C90JW+P;CT6)Q40!
MXD&)S$$A]4'!Q`5$`>)%B<1!"?1!(<S!R0)%">Q$BZPDR````$*-A"C<O!N/
M08GU1`'@08G402'-0<'$!40!X$&)]$$)S$$AU$4)[$2+K"3,````1XV$*-R\
M&X]!B<U%`>!!B<3!R@)!P<0%02'510'@08G,00G402'$P<@"10GL1(NL)-``
M``!"C;0NW+P;CT&)U40!YD6)Q$$AQ4'!Q`5$`>9!B=1!"<1%(<1!P<@"10GL
M1(NL)-0```!"C8PIW+P;CT&)Q40!X4&)]$4AQ4'!Q`5$`>%!B<1%"<1!(?3!
MS@)%">Q$BZPDV````$*-E"K<O!N/18G%1`'B08G,02'U0<'$!40!XD6)Q$$)
M]$$AS$4)[$2+K"3<````0HV$*-R\&X]!B?5$`>!!B=3!R0)!P<0%02'-1`'@
M08GT00G,02'4P<H"10GL1(NL).````!'C80HW+P;CT&)S44!X$&)Q$$AU4'!
MQ`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDY````$*-M"[<O!N/08G51`'F18G$
M02'%0<'$!40!YD&)U$$)Q$4AQ$'!R`)%">Q$BZPDZ````$*-C"G<O!N/08G%
M00',B?%%(<7!P05!`<R)P40)P2'Q1`GI1(NL).P```!"C90JW+P;CP'*1(GA
MP<X"P<$%08GU`<J+C"3P````C80(UL%BRD2)P3'Q1#'A0<',`@'!B=!$,>;!
MP`4QU@'!BX0D]````$&-A`#6P6+*`<:)R,'`!0'&B="+E"3X````P<@"08V4
M%=;!8LI%B>5!,<5!,<W!R0)!`=6)\D&)R(G!P<(%1#'!00'5BY0D_````#'Q
MP<X"08V4%-;!8LI$BZ0D!`$```'11(GJP<(%1XVD(-;!8LH!T8N4)``!``"-
MA!#6P6+*1(G"08GP,?)$,>H!PHG(P<`%`<)$B>C!R`)!,<!!,<C!R0)%`>!!
MB=1!P<0%10'@1(ND)`@!``!&C:0FUL%BRHG&,<XQUL'*`D0!YD6)Q$'!Q`5$
M`>9$BZ0D#`$``$:-I"#6P6+*B<@QT$0QP$'!R`)$`>!!B?1!P<0%1`'@1(ND
M)!`!``!&C:0AUL%BRHG11#'!,?'!S@)$`>%!B<1!P<0%1`'A1(ND)!0!``!&
MC:0BUL%BRD2)PC'R,<+!R`)$`>)!B<Q!P<0%1`'B1(ND)!@!``!'C80@UL%B
MRD&)]$$QQ$$QS,')`D4!Q$&)T$'!P`5%`<1$BX0D'`$``$*-M`;6P6+*08G`
M03'(03'0P<H"00'P1(GFP<8%00'PB[0D(`$``(VT,-;!8LJ)R#'01#'@0<',
M`@'P1(G&P<8%`?"+M"0D`0``C8PQUL%BRHG61#'F1#'&0<'(`@'.B<'!P04!
MSHN,)"@!``"-E`K6P6+*1(GA1#'!,<'!R`(!T8GR08G%P<(%`=&+E"0L`0``
M08V4%-;!8LI%B<1!,<1!,?1!`=2)RL'.`L'"!4$Q]4$!U(N4)#`!``!!,<W!
MR0)!C900UL%BRD6)X$$!U42)XD'!R`+!P@5!`=6+E"0T`0``C900UL%BRHGP
M,<A$,>!!B<P!T$2)ZD4QQ,'"!44Q[`'0BY0D.`$``(V4%M;!8LI$B>Y!`=2)
MPL'.`L'"!4$!U(N4)#P!``!%`>.-E!76P6+*9T2)7P0!T42)PC'R1`'.,<+!
MR`)GB7<,`<I$B>%!`<+!P05G1(E7"`'*00'89XD79T2)1Q"+A"1,`0``9#,$
M)1@```!U#8'$6`$``%M=05Q!7</H!>W__P\?1```05=!5D%505154X/L"$B%
M_P^$N@```(L%-(L``&=$BRA%A>T/A*<```!G#[8'28G_28GTA,!T!#P]=4U%
M,?9G08M=`(7;="U$B>UF#Q]$``")WT2)\DR)_NC#Z___A<!U"&="@#PS/70_
M9XM=!(/%!(7;==R#Q`B)V%M=05Q!74%>05_##Q]``$&)_F=!#[9&`4&#Q@&$
MP'0$/#UU[D4I_NN<9@\?1```1"GM0HU<,P'!_0*)V&=!B2PD@\0(6UU!7$%=
M05Y!7\,/'X0``````(/$"#';B=A;74%<05U!7D%?PV9F+@\?A```````#Q\`
M55-(B?N#[!ADBP0E&````(E$)`PQP(UL)`AF#Q]$```QP$B)[DB)W^CC_O__
M2(7`="Z+!2B*``"+5"0(9XL`C0209XM0!&>)$(72=-,/'P!GBU`(@\`$9XD0
MA=)U\NO`BT0D#&0S!"48````=0:#Q!A;7</HE^O__P\?@`````!!5T%6055!
M5%5(B?U32(GS@^PH9(L$)1@```")1"0<,<!G@#X]=0.#PP%(B=_HKNS__TB)
M[XUT)!B)1"0(08G&,<#H2?[__TB)QT&)Q87`#X0+`0``Z(;L__]$.?`/@]T`
M``"+1"081(LE<HD``$2--(4`````9P^V10"$P`^$C0$``#P]#X2%`0``B>@/
M'P!G#[90`8/``832=`6`^CUU[RGHBW0D"&=%`S0DC7PP`NC;[/__9T&)!H7`
M#X1H`0``9T&+!"2+5"08C4T!9XL4D&</MD4`9X@"/#UT(83`=0OK&P\?1```
M/#UT$H/!`8/"`6</MD'_9X@"A,!UZF?&`CTQP`\?0`!G#[8,&&>(3`(!@\`!
MA,EU[S'`BW0D'&0S-"48````#X7W````@\0H6UU!7$%=05Y!7\,/'T0``#'`
M9@\?1```9P^V%!AG08A4!0"#P`&$TG7NZ[T/'T``1(LE>8@``&=%BSPD9T&+
M#X7)#X2?````13'M#Q]$``!$B>A!@\4!9T.+%*^%TG7PC32%#````(L%DYH`
M`(7`=4_'!86:```!````B??HWNO__XE$)`Q(B<>%P'1L1HTTK0````!$B?Y$
MB?+H,.G__T2+1"0,9T&)!"1G0\=$J`0`````1(EL)!CIB/[__V:01(G_Z'CI
M__]G08D$)$&)P(7`="5&C32M`````.O,9I`QP.F,_O__O@@```!%,>WI<___
M_^AGZ?__@\C_Z>K^__]F9BX/'X0```````\?0`!!5D%505154X'LH````&2+
M!"48````B80DG````#'`2(7_=`EG@#\`2(G]=2N+A"2<````9#,$)1@````/
MA04!``"!Q*````!;74%<05U!7L,/'X``````Z+/G__]$C2US)P``08G$A<!T
MPDR)Y^B]Y___A<`/A)T```!G9H-X$RZ-6!-TY6=F@7@3+BX/A)T```!(B>_H
M!>K__TB)WT&)QNCZZ?__08U\!@+HH.K__T2)Z4F)V4F)Z$F)QDB)Q[K_____
MO@$````QP.@`ZO__OP$```")XDR)]NB1Z/__3(GW@_C_=!"+1"08)0#P```]
M`$```'1)Z#3J__],B??H?.?__TR)Y^@DY___A<`/A6?___\/'T``3(GGZ'#G
M__](B>_HF.G__^D`____#Q\`9X![`@`/A##____I4____^B[_O__Z[7H!.C_
M_P\?0`!52(G^2(G]OP$```"![*````!DBP0E&````(F$))P````QP(GBZ(;I
M__^%P'4RBU0D&('B`/```('Z`$```'0(@?H`H```=1J^`@```$B)[^C[YO__
MA<`/E,`/ML#K`Y`QP(N,))P```!D,PPE&````'4(@<2@````7</H@.?__T%7
MNO\/``!!5D%528GU05152(G]C3WS)0``@>P0$```9(L$)1@```")A"0,$```
M,<")YDF)].B%Z?__A<!^>8L56X4``&>`?`3_`$2-</]G1(LZ=5M%A?9T:$2)
M\KXO````3(GGZ#;H__](A<!T4T2)_^A)Z/__1(GQ3(GB2(GN2(G'Z,CG__^+
MA"0,$```9#,$)1@```!U08'$$!```%U!7$%=05Y!7\,/'X``````08G&ZZ4/
M'P"+!>*$``!G1(LX1(G_Z/;G__],B>I(B>Y(B<?HF.;__^NNZ*'F__^0@^P(
MBP6WA```9XLXZ,_G__^+%=&$``"#Q`B-#1!D``!(B<>--1,E``#IDNC__V:0
M4XL=B80``&>+.^BAY___2(G'Z+G___]GBSOHD>?__XT-<28``$4QR5O'PC!-
M0`!(B<=)B<B-->TD``#ID.;__T%455.!["`@``!DBP0E&````(F$)!P@```Q
MP(GE1(VD)!`0``#HEN;__TB)[XT-RB0``$2-#8XD``!!B<"Z`1```+X!````
M,<#H8N?__TB)[[H`$```3(GFZ!+H__\Q[87`>".->`&)P^C"Y___2(G'B<6%
MP'00B=I,B>;H+^;__V?&1!T``(N,)!P@``!D,PPE&````(GH=0N!Q"`@``!;
M74%<P^B&Y?__9@\?1```Z4O___]F9BX/'X0``````$%7059)B?9!54%454B)
M_8T]-"0``%.![+@0``!DBP0E&````(F$)*P0```QP(UT)`SH.OC__[XO````
M2(GOB</H"^;__TB%P'0^2(GNC3W_(P``,<#HAOG__XN<)*P0``!D,QPE&```
M`(GH#X5U`0``@<2X$```6UU!7$%=05Y!7\-F#Q]$``!(B>]$C27-(P``Z"GF
M__],B>9,B?=!B<7H^^3__T&#Q0%!B<>%P'2:9T&`/P`/A,P````/'T0``$6)
M_H7;=!*)WTR)]N@_Y?__A<`/A(X```!,B??HW^7__V=!@'P'_R]U&$&-5_]F
MD(/H`6?&1`(!`&=!@'P'_R]T[D0!Z#W_#P``#X\Z____C0TQ)```18GXN@`0
M```QP$2-M"2@````@^P(O@$```!51(T-*2,``$R)]^BPY?__C50D($R)]K\!
M````Z#_D__]:687`=1"+1"0H)0#P```]`(```'113(GF,?_H+^3__T&)QX7`
M#X3._O__9T&`/P`/A3G___^%VW0&9X`[+G071(T]72(``+@!````Z6#___]F
M#Q]$``!G@'L!`'2XZ^`/'X``````O@$```!,B??H^^+__X7`=9Y,B?:-/8`B
M``#H"?C__TR)]^BAY/__B<7I=/[__^B%X___#Q]$``!G#[8/A,ET&8GZ9@\?
M1```@\(!@/DO9P^V"@]$^H3)=>^)^,-F9BX/'X0``````)!(A?\/A,<```!5
M2(G]4X/L"&>`/P`/A(4```#H@.3__XU4*/\YZG<3Z8,````/'P"#Z@$YZ@^$
M?0```&>`.B]T[SGJ=FL/'P"#Z@$YZG1I9X`Z+W7S.>IU#>M%#Q]$``!G@#HO
M=0>#Z@$YZG?S*>HQP(U*`H'Y`!```'<;C3UN@P``@\(!N0`0``!(B>Y(B?OH
M:^/__XG8@\0(6UW##Q\`@\0(C3TL(0``6UWIL./__SGJ=;(/'T``9X`Z+W3B
M@\0(C3UZ(0``6UWIDN/__V:0C3W_(```Z87C__\/'T0``$%6,=*-/5DA``!$
MC36/(0``055$C2TO(0``051$C25A(0``58TM@"$``%.#[$!F#V\%VE\``&2+
M!"48````B40D/#'`9HE4)#`/*40D$&8/;P7*7P``#RE$)"#H`/;__S'`C3T$
M(0``Z//U__\QP(T]_R```.CF]?__,<"-/?L@``#HV?7__S'`3(GGZ,_U__\Q
MP(T]^R```.C"]?__,<!,B>_HN/7__S'`3(GWZ*[U__\QP$B)[^BD]?__,<"-
M/?`@``#HE_7__S'`C3V!(```Z(KU__^-="0,,<"-/=P@``!(B?/HAO3__X7`
M=`U(B<9(B>\QP.CE]?__B=Z-/<P@```QP.AF]/__2(G&A<!T#8T]RB```#'`
MZ,+U__^)W8T]QB```#'`2(GNZ$#T__](B<:%P'0Y3(GO,<#HG_7__S'`C37/
M(```3(GGZ(_U__^+1"0\9#,$)1@```!U68/$0%M=05Q!74%>PP\?1```2(GN
MC3V#(```,<#H\//__TB)QH7`=!%,B?<QP.A/]?__ZZX/'T0``$BX4$%27T-,
M14%(.40D(7689H%\)"E./76/C70D*^O/Z+/@__\/'P"#[!ADBP0E&````(E$
M)`PQP(L%$8$``(/X_W04BWPD#&0S/"48````=3N#Q!C#9I"-="0(C3VF'P``
M,<#H;_/__TB)PC'`A=)T$V</MA*`^C`/E<$QP(32#Y7`(<B)!<6```#KM^A&
MX/__9@\?1```@^P(Z+C?__^)Q^B!X/__B<*%P'0#9XL0B="#Q`C#9I!!54%4
M1(TE.R```%5(B?U,B>=3@^P89(L$)1@```")1"0,,<"-="0(Z//R__^%P'0&
M9X`X`'4I2(GN3(GG,<#H3/3__XM$)`QD,P0E&````'5]@\086UU!7$%=PP\?
M0`!(B>Y(B<=(B</HHM[__TB%P'712(GOZ/7@__](B=]!B<7HZN#__T&-?`4"
MZ)#A__^#[`BZ_____TF)Z%-(B<=)B<5$C0UF'@``C0U('P``O@$````QP.CE
MX/__3(GN3(GG,<#HR//__UA:Z77____H3-___V9F+@\?A```````D$%7059!
M54%455.!['B!``!(B7PD"(UT)$1)B?5DBP0E&````(F$)&R!```QP(T%PQX`
M`,=$)%``````B40D2(T%@!T``(E$)$R-!5L>``")1"1DC06B'@``B40D:(T%
M9!X``(E$)&R-!98>``")1"1PC05S'@``B40D5(T%AAX``(E$)%B-!8X=``!(
MB40D($B)QS'`QT0D=`````#'1"1<`````.B6\?__A<!T"F>`.``/A?@$```Q
MP.A!_O__B<6%P`^$/P0``(GOZ,#?__^-?``!Z&?@__]G1`^V10")PT6$P'0S
M08G<1(T](!X``$2)YTR)^;K_____O@$````QP(/%`4&#Q`+HLM___V=$#[9%
M`$6$P'771(U\)&"-!8T=``!%B>SK&`\?@`````!G08M'!$&#QP2%P`^$CP$`
M`(G'3(GF,<#H\_#__TB)Q87`=-QG@#@`=-9(B<?HWO7__X7`=,I(B>_HXM[_
M_T&)QH7`#X17`0``#Q^``````$2)\6>+$8/!!(V"__[^_O?2(=`E@("`@'3I
MB<+!ZA"I@(````]$PHU1`@]$RHG"`,*)VH/9`T0I\6>+,H/"!(V&__[^_O?6
M(?`E@("`@'3IB<9$C258'```P>X0J8"````/1,:-<@(/1-:)QD``QH/:`RG:
M1(V\$00$``!$B?_H/-___TV)X46)\+K_____B40D%$B)Q8T%`AT``(T-\QP`
M`%.^`0```$B)[U`QP.B-WO__OL`!``!(B>_H\-W__T%805F#^/]U$^C"W/__
M9T2+"$&#^1$/A2$#``"-E"2`````2(GNOP$```")5"0HZ'S>__^)PX7`#X2R
M````BT0D"$F)Z+X!````13'MC14]'0``9XL(BP4$>P``9XLX,<#H6M[__XN$
M)&R!``!D,P0E&`````^%*@@``('$>($``$R)Z%M=05Q!74%>05_#D(M$)$B-
M;"1(ZQ%F#Q]$``!GBT4$A<!T.(/%!&>`.`!T+T&)Q$R)Y^A$]/__A<!TX$R)
MY^A(W?__08G&A<`/A6W^__]GBT4$A<!US0\?1```13'VZ5C^__\/'X0`````
M`(N$))@````E`/```#T`0```#X4W____BX0DG````$&)QNAJV___03G&#X4?
M____BX0DF````"7_`0``/<`!```/A0C___]$B?_HPMW__XT]GQL``$2)[DB)
M1"08B40D+#'`Z*GN__](B<>%P`^$+@(``.BIW/__2(G&BT0D"&>+..@:]O__
M08G%A<`/A`\"``!$B>_HQ]S__X/X`W8Z08UT!?RY!0```(T]2AL``&?SI@^7
MPH#:`(32=1V#^`0/A)X%``!G08!\!?LO#X21!0``#Q^``````#'`Z('Z__^%
MP'451(GO,?;HL]K__T&)Q87`#X6U`0``C36Z&@``C3T\&@``,<#H=>___T2-
M-20;``!$C3T&&P``Z(+;__]!5DF)Z+K_____4$B+?"0H38GAC0W:&@``O@$`
M```QP.A-W/__6%I(B6PD"$2+;"0LBVPD%.L]#Q\`Z(/:__]G@S@1=4'H.-O_
M_X/#`8/L"$2)^4%638GA08GHNO____]3O@$```!,B>]0,<#H`=S__X/$(+[`
M`0``3(GOZ&';__^#^/]TM$B+;"0(2(GOZ(_9__](BUPD&$B+?"0@,<!(B=[H
MN^[__TB)W^@C^O__Z:3]__]F#Q]$``!$C60D5(T%UQD``$2)Z^L6#Q^$````
M``!G08M$)`2%P'0V08/$!(G'2(G>,<#H!NW__TB)QX7`=-]G@#@`=-GH!-O_
M_XG%A<`/A7/[__]G08M$)`2%P'7*OPT```"-+809``#HT-O__T&X4P```(G#
MZ6G[__^+1"0(28GHO@$```!%,>V-%?X9``!GBPB+!05X``!GBS@QP.A;V___
MZ?S\__]F#Q]$``!(B<5(B<?H9?G__TB)[^B-VO__28G%Z=O\__\/'T0``(M$
M)`AG1(LHZ>3]__^Z`@```$C'QN[___^)Q^A@V___C9PD8`$``+H&````1(GO
M2(G>B5PD".C%VO__@+PD8`$```!U#H"\)&$!``!##X0[!```,=(Q]D2)[^@A
MV___2(EL)#!(N`$C16>)J\WO2(F$)(````!(N/[<NIAV5#(02(F$)(@```"X
M\.'2PTB)A"20````C80DG````,>$))@`````````QX0DW`````````")1"04
M3(ED)#@/'T0``$2+?"0(N@"```!$B>],B?[H*]K__T&)QH7`#XXW`0``,<E"
MC03U`````(ML)`@#A"24````BY0DF`````^2P8F$))0```!$B?"#^0&#VO_!
MZ!T!T(N4)-P```")A"28````A=(/A9X```!!@_X_#X[4`@``18UFP$2+="0H
M18GG0<'O!D&-7P'!XP8!ZP\?`&?S#V]-`&?S#V]5$$R)]X/%0&?S#V]=X&?S
M#V]E\`\1C"2<````#Q&4)*P````/$9PDO`````\1I"3,````Z$W=__\YZW6Y
M0<'G!D6)YD4I_HM\)!2)WKE$````1(GRZ'S8__]$B;0DW````.G__O__#Q^`
M`````+A`````3(G^*=!!.<9!#T[&B<6+1"04C3P0B>KH!]C__XN$)-P````!
MZ(F$)-P```"#^$`/A;[^__^+?"0H02GN`VPD".C.W/__Z1/___]$B>](BVPD
M,$R+9"0XZ*?6__^+A"24````2(N<))0```#!Z`-(#\N#X#]GQH0$G````("-
M2`&#^3@/CKD!``"+="04ND`````!SBG*=`XQP&?&!`8`@\`!.=!R](M\)"CH
M9-S__V8/[\!(QX0DS``````````/$80DG`````\1A"2L````#Q&$)+P```"+
M?"0H1(VL)!$!``!(B9PDU````$2-/8$6``#H'-S__XN$)(`````/MY0D@```
M`(G#P>@0B(0D$0$``,'K&&;!P@B+A"2$````9HF4)!(!``!!B=B-G"18`0``
M#\B)A"04`0``BX0DB`````_(B80D&`$``(N$)(P````/R(F$)!P!``"+A"20
M````#\B)A"0@`0``C80D,`$``(E$)`A!B<;I#P````\?1```9T4/MD4`08/%
M`42)]T4/ML!,B?FZ_____[X!````,<!!@\8"Z'?7__]$.?-UTL:$)%@!````
MC04*%@``4$2+;"00055(BWPD*+X!````38GA,<"-#;D5``!)B>BZ_____^@Z
MU___65Y$BVPD+.E'^___BT0D"&=$BW`$187V#X1D^O__1(GWZ.36__^#^`,/
MAE/Z__]!C70&_+D%````C3UH%0``9_.F#Y?`'`"$P$4/1.[I,/K__XGKZ9+]
M__^+1"04NC@````Q]BG*`<B#^@AS+?;"!`^%U````(72#X1P_O__9\8``/;"
M`@^$8_[__S'_9V:)?!#^Z5;^__]FD(U("&=(QP``````9TC'1!#X`````(/A
M^"G(`="#X/B#^`@/@BS^__^#X/@QTF=(B301@\((.<)R].D6_O__@+PD8@$`
M`$$/A;?[__^`O"1C`0``0P^%J?O__X"\)&0!``!(#X6;^___@+PD90$``$4/
MA8W[__^Z`@```$C'QL;___]$B>_HIM;__[HI````2(G>1(GOZ!;6__^-!:84
M``!04^F=_O__9@\?A```````9\<``````&?'1!#\`````.F/_?__Z%;4__]F
M#Q]$``!!5T%6055!5%53@^P8BRU=<@``9(L$)1@```")1"0,,<!GBWT`Z&;5
M__]GBWT`B</H6]7__V</ME-DC70D"(T](!,``$F)]6>(4&4QP.C^YO__A<!T
M"F>`.#$/A.`"```QP.AY\?__9XM]`.@@U?__N0L```"Z`0```(TU\!,``$B)
MQ^B(T___A<`/A,````!GBT`,@SU=A````6=$BWT`9T2+8!@/CJH````QV^LZ
MD&=!BW8,BP4YA```1(US`6>+?)@$Z"?4__]!B<"+!2:$``!%A<`/A?`!``"#
MPP(YPT2)\P^-X@$``$2)_^B?U/__,<F)VDR)YDB)Q^A0U/__A<`/A+@!``!G
M1(LP9T2+?0!G08M&""4`!"``/0`$``!TCD2)_^AFU/__1(GVN0(````QTDB)
MQ^ADU?__9T2+?0")QNEM____#Q^$``````!G1(M]`$2)_^@SU/__N0,```"Z
M`0```(TU"!,``$B)Q^B;TO__08G$A<!T-&>+0`QGBWT`9XL8Z`34__^-%>42
M``!(B<>)WNBDTO__9T&+1"0,9XL89_9#"D`/A<D!``!GBWT`Z-?3__^Y`P``
M`+H!````C36S$@``2(G'Z#_2__^)PX7`=#A$B>Z-/5(1```QP.AIY?__28G$
MA<`/A%X!``!GBT,,9XM]`&>+&.B.T___3(GB2(G'B=[H,=+__V>+?0#H>-/_
M_[H!````C35;$@``2(G'Z"71__]GBWT`28G$Z%G3__^-%582``!,B>9(B<?H
M^-'__V>+?0#H/]/__T2)[HT]SQ```&?&0&4`,<#HZN3__XD%D((``(G"A<`/
MA)H```!!B=2^P`$``$R)Y^BZTO__C5`!@_H!=@F#^!$/A?\```"+1"0,9#,$
M)1@````/A>@```"#Q!A;74%<05U!7D%?PV8/'X0``````(L%,H(``&=$BWT`
MC5#_.=H/A7_^__^#^`$/CG;^__^[`0````\?0`!$B?^#PP'HG=+__TR)YDB)
MQ^@"T?__.1WT@0``9T2+?0!_W>E%_O__BSW>@0``Z/7Q__^)!=N!``")PH7`
M#X5+____C3T'$@``Z.K2__]F+@\?A```````9X!X`0`/A!S]___I$/W__XL%
MGH$``&>+?0!G1(L@9XM##&>+&.@FTO__1(GFB=_H7.G__^F6_O__9XM]`.@.
MTO__B=Y(B<?H)-+__^D?_O__Z+K0__^+%5B!``")P8T]O!$``#'`9XLR3(GB
MZ&_2__]F9BX/'X0```````\?0`!52(G]4X/L".@S[?__2(G'Z/OL__](B<,Q
MP.C![___A<!T)4B%[70@9X!]``!T&;D$````C3TT$```B=YG\Z8/E\`<`(3`
M=`B#Q`A;7<-FD(/$"$B)[UM=Z>/F__\/'P#S#Q[Z05=$C3TC;0``059)B=9!
M54F)]4%408G\58TM$6T``%-$*?V#[`CH@<[__\']`G0C,=MF+@\?A```````
M9T&+!)^#PP%,B?),B>Y$B>?_T#G==>F#Q`A;74%<05U!7D%?PV9F+@\?A```
M````\P\>^L-F+@\?A```````D/,/'OJ+#1IP``#I0='__P#S#Q[Z2(/L"$B#
MQ`C#````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M
M`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#0U`"UE`"TM```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$;
M`SOH````'````."`__\L`0``H(3__U@&``#`AO__!`$``/"&__\8`0``L(?_
M_U`!``!`E?__D`$``#"6__\(`@``L);__S0"``#PF/__@`(``$":___$`@``
MP)K__^@"``"@F___+`,``-";__]$`P``$)S__V`#``#`G/__E`,``-"<__^H
M`P``P)[__P@$``#PGO__'`0``-"?__]@!```D*'__Z0$````HO__P`0``""B
M___8!````*/__R`%``#PK?__V`4``+"Q__\D!@``$++__X0&``"`LO__S`8`
M`)"R___@!@``%``````````!>E(``7@0`1L,!PB0`0``$````!P```"TA?__
M,`````!$!Q`0````,````-"%__\%`````````"````!$````K'___\`#````
M#A!&#AA*#PMW"(``/QH[*C,D(CP```!H````6(;__XL-````0@X0C0)"#AB,
M`T$.((8$00XH@P5&#H`#`W,-"@XH00X@00X80@X00@X(00L```!T````J```
M`*B3___B`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T,.0`)J
M"@XX0PXP00XH0@X@0@X80@X00@X(10MU"@XX00XP00XH0@X@0@X80@X00@X(
M20M##CA%#C!!#BA"#B!"#AA"#A!"#@@H````(`$``""4__]Y`````$$.$(8"
M00X8@P-&#C`":0H.&$$.$$$."$$+`$@```!,`0``=)3__S$"````0@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1@Y@`QT!"@XX00XP00XH0@X@0@X8
M0@X00@X(1@M`````F`$``&B6__],`0```$(.$(X"0@X8C0-"#B",!$$.*(8%
M00XP@P9&#M`!>@H.,$$.*$$.($(.&$(.$$(."$@+`"````#<`0``=)?__X``
M````00X0A@)1#K`!`F<*#A!!#@A!"T```````@``T)?__]\`````0@X0CP)'
M#AB.`T(.((T$10XHC`5!#C"&!D\.P"`"?PH.,$$.*$(.($(.&$(.$$(."$@+
M%````$0"``!LF/__+@````!##A!7#@@`&````%P"``"$F/__0`````!!#A"#
M`F@."````#````!X`@``J)C__ZH`````0@X0C`)!#AB&`T$.((,$1@[`0`*6
M"@X@00X800X00@X(00L0````K`(``"29__\%`````````%P```#``@``()G_
M_^L!````0@X0CP)"#AB.`T4.((T$0@XHC`5!#C"&!DH..(,'1@[P(0);"@XX
M00XP00XH0@X@0@X80@X00@X(1PL"HP[X(48.@")A#O@A00[P(0```!`````@
M`P``L)K__R0`````````0````#0#``#,FO__VP````!*#A"&`D0.&(,#0PX@
M`HD*#AA!#A!!#@A$"T,*#AA'PPX00<8."$4+40X81\,.$$'&#@A`````>`,`
M`&B;__^]`0```$(.$(X"40X8C0-)#B",!$@.*(8%1PXP@P9##G`#-`$*#C!!
M#BA!#B!"#AA"#A!"#@A&"Q@```"\`P``Y)S__VH`````0PX@:@H."$,+```4
M````V`,``#B=__\>`````$,.$%H."`!$````\`,``$"=___4`````$(.$(T"
M0@X8C`-(#B"&!$<.*(,%0PY`?PH.*$$.($$.&$(.$$(."$4+<PY(20Y0;0Y(
M00Y```"T````.`0``-B=___J"@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T8.L(,"`Q,"#KB#`DD.P(,"5@ZX@P)"#K"#`@)]"@XX1`XP00XH
M0@X@0@X80@X00@X(0@L#@`$.N(,"20[`@P);#KB#`D$.L(,":0ZX@P)%#L"#
M`DP.R(,"20[0@P)*#K"#`@.;!`ZX@P)'#L"#`F,.N(,"00ZP@P(#.0$*#KB#
M`D$.P(,"3@L`2````/`$```0J/__L0,```!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P=##E`#GP(*#CA!#C!!#BA"#B!"#AA"#A!"#@A*"S`````\
M!0``A*O__UT`````00X0A@)$#AB#`T,.(`)#"@X800X000X(0PM##AA$#A!!
M#@@H````<`4``$!^__\:`@```$(.$(P"00X8A@-##D`#<0$*#AA$#A!"#@A!
M"T0```"<!0``A*O__V4`````1@X0CP))#AB.`T4.((T$10XHC`5$#C"&!D<.
M.(,'1@Y`<`XX00XP00XH0@X@0@X80@X00@X(`!````#D!0``K*O__P4`````
M````$````/@%``"HJ___#P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#@)D``L"9```$````!
M`````0```,T!```!````V`$```$```#B`0```0```#$"```!````;@,```\`
M``"Q!```#``````@0``-````X%%``!D```"`OD``&P````0````:````A+Y`
M`!P````$````]?[_;_0!0``%````Z`A```8```#(`D``"@```/0$```+````
M$````!4``````````P````#`0``"````Q`(``!0````'````%P```'`/0``'
M````X`Y```@```"0````"0````P```#^__]OH`Y``/___V\"````\/__;]P-
M0```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"(OD`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0`````````````````#_____V&)``$=#0SH@*%!,1"U,:6YU>"D@
M.2XR+C`@,C`Q.3`X,3(@*')E;&5A<V4I`$=#0SH@*%!,1"U,:6YU>"D@.2XR
M+C`@,C`Q.3$Q,3@@*')E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N;F]T
M92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD
M>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R
M86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y
M;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````"P````$````"
M````E`%``)0!```:```````````````!`````````!,````'`````@```+`!
M0`"P`0``)```````````````!``````````F````!P````(```#4`4``U`$`
M`"````````````````0`````````-````/;__V\"````]`%``/0!``#4````
M!0`````````$````!````#X````+`````@```,@"0`#(`@``(`8```8````!
M````!````!````!&`````P````(```#H"$``Z`@``/0$``````````````$`
M````````3@```/___V\"````W`U``-P-``#$````!0`````````"`````@``
M`%L```#^__]O`@```*`.0`"@#@``0`````8````"````!`````````!J````
M!`````(```#@#D``X`X``)`````%``````````0````,````=`````0```!"
M````<`]``'`/``#$`@``!0```!8````$````#````'X````!````!@`````@
M0```(```&P``````````````!`````````!Y`````0````8````@($``("``
M`,`#`````````````!`````0````A`````$````&````X"-``.`C``#_+0``
M```````````0`````````(H````!````!@```.!10`#@40``#0``````````
M````!`````````"0`````0````(`````8$```&```$`_`````````````!``
M````````F`````$````"````0)]``$"?``#L```````````````$````````
M`*8````!`````@```"R@0``LH```#`8`````````````!`````````"P````
M#@````,```"`OD``@*X```0```````````````0````$````O`````\````#
M````A+Y``(2N```$```````````````$````!````,@````&`````P```(B^
M0`"(K@``&`$```8`````````!`````@```#1`````0````,```"@OT``H*\`
M`&````````````````@````(````U@````$````#`````,!```"P``#P`0``
M```````````(````"````-\````!`````P```/#!0`#PL0``$```````````
M````!`````````#E````"`````,`````PD```+(``#00`````````````"``
M````````Z@````$````P``````````"R``!4```````````````!`````0``
I``$````#``````````````!4L@``\P```````````````0``````````
